==> haskell-snap-core-1.0.4.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.4.0
id: snap-core-1.0.4.0-FwYilkzGjLZKoTvxMmQdxW
key: snap-core-1.0.4.0-FwYilkzGjLZKoTvxMmQdxW
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: 195dd202198d05110890c36bb8af2191
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.5/site-local/snap-core-1.0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/snap-core-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/snap-core-1.0.4.0
hs-libraries: HSsnap-core-1.0.4.0-FwYilkzGjLZKoTvxMmQdxW
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.1.0-46RQH784My91OHHMmubhfr
    lifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3 mtl-2.2.2
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
    unix-compat-0.5.1-7L4ZE9qc5MBJa5Jne6W69O
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-snap-core-1.0.4.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-snap-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: snap-core
version: 1.0.4.0
id: snap-core-1.0.4.0-JXezj0tDfRUCk5lTgfqmSl
key: snap-core-1.0.4.0-JXezj0tDfRUCk5lTgfqmSl
license: BSD-3-Clause
maintainer: snap@snapframework.com
author: Snap Framework Authors (see CONTRIBUTORS)
homepage: http://snapframework.com/
synopsis: Snap: A Haskell Web Framework (core interfaces and types)
description:
    Snap is a simple and fast web development framework and server written in
    Haskell. For more information or to download the latest version, you can
    visit the Snap project website at <http://snapframework.com/>.
    .
    This library contains the core definitions and types for the Snap framework,
    including:
    .
    1. Primitive types and functions for HTTP (requests, responses, cookies,
    post/query parameters, etc)
    .
    2. A monad for programming web handlers called \"Snap\", which allows:
    .
    * Stateful access to the HTTP request and response objects
    .
    * Monadic failure (i.e. MonadPlus/Alternative instances) for declining
    to handle requests and chaining handlers together
    .
    * Early termination of the computation if you know early what you want
    to return and want to prevent further monadic processing
    .
    /Quick start/: The '\''Snap'\'' monad and HTTP definitions are in "Snap.Core".
category: Web, Snap, IO-Streams
abi: c0a35bb40423ebec917c01e78c36a6e4
exposed: True
exposed-modules:
    Snap.Core Snap.Internal.Core Snap.Internal.Debug
    Snap.Internal.Http.Types Snap.Internal.Parsing Snap.Test
    Snap.Types.Headers Snap.Util.CORS Snap.Util.FileServe
    Snap.Util.FileUploads Snap.Util.GZip Snap.Util.Proxy
hidden-modules: Snap.Internal.Instances Snap.Internal.Routing
                Snap.Internal.Test.RequestBuilder Snap.Internal.Test.Assertions
                Snap.Internal.Util.FileServe Snap.Internal.Util.FileUploads
import-dirs: /usr/lib/ghc-8.6.5/site-local/snap-core-1.0.4.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/snap-core-1.0.4.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/snap-core-1.0.4.0
hs-libraries: HSsnap-core-1.0.4.0-JXezj0tDfRUCk5lTgfqmSl
depends:
    HUnit-1.6.0.0-Kc3RXVOuMSQ9Y4PmNrdWEj
    attoparsec-0.13.2.2-JtccVfLzqCgD0Y1SyaKt8t base-4.12.0.0
    bytestring-0.10.8.2 case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk
    containers-0.6.0.1 directory-1.3.3.0 filepath-1.4.2.1
    hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    io-streams-1.5.1.0-46RQH784My91OHHMmubhfr
    lifted-base-0.2.3.12-B68iwk5BNXFLXLdjdYGHmp
    monad-control-1.0.2.3-EKrTS47Oi8IKd1pTyskzd3 mtl-2.2.2
    network-2.8.0.0-HTKosw7lwpaCVnkz1nc19d
    network-uri-2.6.1.0-K75fCYvLQE41EntOQ30cqK
    old-locale-1.0.0.7-D4Rn5zPhtMJBwwirPJNu78
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    readable-0.3.1-7I5EIROpRuwBi3cHo2WBVY
    regex-posix-0.95.2-jmiKTXBn5tB7yYph2GqnC text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-KWttVZ7nb0vsLFTQBq79t
    unix-compat-0.5.2-GYmNPGqdGR3DF85i5Y9m4X
    unordered-containers-0.2.10.0-1NpUw7eLrexDi5zNhT27CT
    vector-0.12.0.3-2LEYu9M2i7lERDtz76XG3n
haddock-interfaces: /usr/share/doc/haskell-snap-core/html/snap-core.haddock
haddock-html: /usr/share/doc/haskell-snap-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
